@@ -1,21 +1,8 @@
-/* Copyright 2008  Rolf Eike Beer <kde@opensource.sf-tec.de>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+/*
+    SPDX-FileCopyrightText: 2008 Rolf Eike Beer <kde@opensource.sf-tec.de>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 #include "keytreeview.h"
 
 #include "model/keylistproxymodel.h"
@@ -172,7 +159,7 @@ KeyTreeView::contentsDropEvent(QDropEvent *o)
 					KGuiItem(i18n("Do Not Import"))) != KMessageBox::Yes)
 			return;
 
-		emit importDrop(uriList);
+		Q_EMIT importDrop(uriList);
 	}
 }
 
@@ -219,7 +206,7 @@ KeyTreeView::keyPressEvent(QKeyEvent *event)
 {
 	if (event->key() == Qt::Key_Return) {
 		if (!event->isAutoRepeat())
-			emit returnPressed();
+			Q_EMIT returnPressed();
 
 		return;
 	}
